@@ -8,10 +8,11 @@ use Try::Tiny;
 use Locale::TextDomain qw(App-Sqitch);
 use App::Sqitch::X qw(hurl);
 use Hash::Merge 'merge';
+use File::Path qw(make_path);
 use Moo;
 use App::Sqitch::Types qw(Sqitch Target);
 
-our $VERSION = 'v1.2.1'; # VERSION
+our $VERSION = 'v1.3.0'; # VERSION
 
 use constant ENGINES => qw(
     pg
@@ -239,7 +240,7 @@ sub parse_args {
         $seen{$target->name}++;
     }
 
-    # Iterate over the argsx to look for changes, engines, plans, or targets.
+    # Iterate over the args to look for changes, engines, plans, or targets.
     my %engines = map { $_ => 1 } ENGINES;
     for my $arg (@{ $p{args} }) {
         if ( !$p{no_changes} && $target && -e $target->plan_file && $target->plan->contains($arg) ) {
@@ -309,6 +310,22 @@ sub parse_args {
     return (@names, \@targets, $rec{changes});
 }
 
+sub _mkpath {
+    my ( $self, $dir ) = @_;
+    $self->debug( '    ', __x 'Created {file}', file => $dir )
+        if make_path $dir, { error => \my $err };
+
+    my $diag = shift @{ $err } or return $self;
+
+    my ( $path, $msg ) = %{ $diag };
+    hurl $self->command => __x(
+        'Error creating {path}: {error}',
+        path  => $path,
+        error => $msg,
+    ) if $path;
+    hurl $self->command => $msg;
+}
+
 1;
 
 __END__
@@ -751,7 +768,7 @@ David E. Wheeler <david@justatheory.com>
 
 =head1 License
 
-Copyright (c) 2012-2021 iovation Inc., David E. Wheeler
+Copyright (c) 2012-2022 iovation Inc., David E. Wheeler
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
