@@ -15,7 +15,7 @@ use namespace::autoclean;
 
 extends 'App::Sqitch::Engine';
 
-our $VERSION = 'v1.2.1'; # VERSION
+our $VERSION = 'v1.3.0'; # VERSION
 
 sub _dt($) {
     require App::Sqitch::DateTime;
@@ -181,7 +181,7 @@ sub _ts2char_format {
 sub _ts_default { 'current_timestamp' }
 
 sub _listagg_format {
-    return q{GROUP_CONCAT(%s SEPARATOR ' ')};
+    return q{GROUP_CONCAT(%1$s ORDER BY %1$s SEPARATOR ' ')};
 }
 
 sub _regex_op { 'REGEXP_LIKE' }
@@ -568,7 +568,7 @@ David E. Wheeler <david@justatheory.com>
 
 =head1 License
 
-Copyright (c) 2012-2021 iovation Inc., David E. Wheeler
+Copyright (c) 2012-2022 iovation Inc., David E. Wheeler
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
